@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: distributive
 version: 0.5.0.2
-id: distributive-0.5.0.2-921805b919081e64e9b7d8c792bc35e0
-key: distr_Iqj9cxS6cgVCp5HcPIq5Qf
+id: distributive-0.5.0.2-17a8848c95a42a5c612669379433d996
+key: distr_BKQYwQkbAEx0aUb1qZp1uR
 license: BSD3
 copyright: Copyright (C) 2011-2016 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -21,11 +21,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/distributive-0.5.0.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/distributive-0.5.0.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/distributive-0.5.0.2
-hs-libraries: HSdistributive-0.5.0.2-Iqj9cxS6cgVCp5HcPIq5Qf
+hs-libraries: HSdistributive-0.5.0.2-BKQYwQkbAEx0aUb1qZp1uR
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    base-orphans-0.5.0-a13c08e02979420be3bfcfc755842cf4
-    tagged-0.8.2-849e3b2865ae1877e32ec9d4d01c3d0a
+    base-orphans-0.5.1-066f51369735933a8c1cc4e054dd01ca
+    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
 haddock-interfaces: /usr/share/doc/haskell-distributive/html/distributive.haddock
